@@ -2055,7 +2055,9 @@ class Class(hyperdb.Class):
                             # don't export empties
                             continue
                         elif isinstance(prop, Date):
-                            value = value.get_tuple()
+                            # this is a hack - some dates are stored as strings
+                            if not isinstance(value, type('')):
+                                value = value.get_tuple()
                         elif isinstance(prop, Interval):
                             value = value.get_tuple()
                         elif isinstance(prop, Password):
