@@ -759,7 +759,10 @@ class Class(hyperdb.Class):
                     setattr(row, key, 0)
                 else:
                     setattr(row, key, int(calendar.timegm(value.get_tuple())))
-                changes[key] = str(oldvalue)
+                if oldvalue is None:
+                    changes[key] = oldvalue
+                else:
+                    changes[key] = str(oldvalue)
                 propvalues[key] = str(value)
 
             elif isinstance(prop, hyperdb.Interval):
