@@ -329,7 +329,6 @@ class Database(Database):
                     self.cursor.fetchall():
                 nodeid = int(nodeid)
                 journaldate = date.Date(journaldate)
-                params = eval(params)
                 olddata.append((nodeid, journaldate, journaltag, action,
                     params))
 
@@ -342,8 +341,9 @@ class Database(Database):
 
             # re-create journal table
             self.create_journal_table(klass)
+            dc = self.hyperdb_to_sql_value[hyperdb.Date]
             for nodeid, journaldate, journaltag, action, params in olddata:
-                self.save_journal(cn, cols, nodeid, journaldate,
+                self.save_journal(cn, cols, nodeid, dc(journaldate),
                     journaltag, action, params)
 
             # make sure the normal schema update code doesn't try to
@@ -496,6 +496,13 @@ class Database(Database):
             print >>hyperdb.DEBUG, 'setid', (self, sql, vals)
         self.cursor.execute(sql, vals)
 
+    def clear(self):
+        rdbms_common.Database.clear(self)
+
+        # set the id counters to 0 (setid adds one) so we start at 1
+        for cn in self.classes.keys():
+            self.setid(cn, 0)
+
     def create_class(self, spec):
         rdbms_common.Database.create_class(self, spec)
         sql = 'insert into ids (name, num) values (%s, %s)'
