@@ -211,7 +211,7 @@ class Database(rdbms_common.Database):
     def newid(self, classname):
         sql = "select nextval('_%s_ids') from dual"%classname
         if __debug__:
-            print >>hyperdb.DEBUG, 'setid', (self, sql)
+            print >>hyperdb.DEBUG, 'newid', (self, sql)
         self.cursor.execute(sql)
         return self.cursor.fetchone()[0]
 
@@ -221,6 +221,14 @@ class Database(rdbms_common.Database):
             print >>hyperdb.DEBUG, 'setid', (self, sql)
         self.cursor.execute(sql)
 
+    def clear(self):
+        rdbms_common.Database.clear(self)
+
+        # reset the sequences
+        for cn in self.classes.keys():
+            self.cursor.execute('DROP SEQUENCE _%s_ids'%cn)
+            self.cursor.execute('CREATE SEQUENCE _%s_ids'%cn)
+
 
 class Class(rdbms_common.Class):
     pass
