@@ -1073,11 +1073,11 @@ class StringHTMLProperty(HTMLProperty):
             return '<a href="mailto:%s">%s</a>'%(s, s)
         else:
             s = match.group('item')
-            s1 = match.group('class')
+            s1 = match.group('class').lower()
             s2 = match.group('id')
             try:
                 # make sure s1 is a valid tracker classname
-                cl = self._db.getclass(s1.lower())
+                cl = self._db.getclass(s1)
                 if not cl.hasnode(s2):
                     raise KeyError, 'oops'
                 return '<a href="%s%s">%s</a>'%(s1, s2, s)
@@ -1503,6 +1503,18 @@ class LinkHTMLProperty(HTMLProperty):
             sort_on=None, **conditions):
         ''' Render a form select list for this property
 
+            "size" is used to limit the length of the list labels
+            "height" is used to set the <select> tag's "size" attribute
+            "showid" includes the item ids in the list labels
+            "additional" lists properties which should be included in the
+                label
+            "sort_on" indicates the property to sort the list on as
+                (direction, property) where direction is '+' or '-'.
+            
+            The remaining keyword arguments are used as conditions for
+            filtering the items in the list - they're passed as the
+            "filterspec" argument to a Class.filter() call.
+
             If not editable, just display the value via plain().
         '''
         self.view_check()
@@ -1657,6 +1669,18 @@ class MultilinkHTMLProperty(HTMLProperty):
             sort_on=None, **conditions):
         ''' Render a form select list for this property
 
+            "size" is used to limit the length of the list labels
+            "height" is used to set the <select> tag's "size" attribute
+            "showid" includes the item ids in the list labels
+            "additional" lists properties which should be included in the
+                label
+            "sort_on" indicates the property to sort the list on as
+                (direction, property) where direction is '+' or '-'.
+            
+            The remaining keyword arguments are used as conditions for
+            filtering the items in the list - they're passed as the
+            "filterspec" argument to a Class.filter() call.
+
             If not editable, just display the value via plain().
         '''
         self.view_check()
@@ -1953,7 +1977,7 @@ env: %(env)s
 '''%d
 
     def indexargs_form(self, columns=1, sort=1, group=1, filter=1,
-            filterspec=1):
+            filterspec=1, search_text=1):
         ''' return the current index args as form elements '''
         l = []
         sc = self.special_char
@@ -1974,7 +1998,7 @@ env: %(env)s
             l.append(s%(sc+'group', val))
         if filter and self.filter:
             l.append(s%(sc+'filter', ','.join(self.filter)))
-        if filterspec:
+        if self.classname and filterspec:
             props = self.client.db.getclass(self.classname).getprops()
             for k,v in self.filterspec.items():
                 if type(v) == type([]):
@@ -1984,7 +2008,7 @@ env: %(env)s
                         l.append(s%(k, ','.join(v)))
                 else:
                     l.append(s%(k, v))
-        if self.search_text:
+        if search_text and self.search_text:
             l.append(s%(sc+'search_text', self.search_text))
         l.append(s%(sc+'pagesize', self.pagesize))
         l.append(s%(sc+'startwith', self.startwith))
@@ -1993,6 +2017,7 @@ env: %(env)s
     def indexargs_url(self, url, args):
         ''' Embed the current index args in a URL
         '''
+        q = urllib.quote
         sc = self.special_char
         l = ['%s=%s'%(k,v) for k,v in args.items()]
 
@@ -2020,23 +2045,24 @@ env: %(env)s
         if self.filter and not specials.has_key('filter'):
             l.append(sc+'filter=%s'%(','.join(self.filter)))
         if self.search_text and not specials.has_key('search_text'):
-            l.append(sc+'search_text=%s'%self.search_text)
+            l.append(sc+'search_text=%s'%q(self.search_text))
         if not specials.has_key('pagesize'):
             l.append(sc+'pagesize=%s'%self.pagesize)
         if not specials.has_key('startwith'):
             l.append(sc+'startwith=%s'%self.startwith)
 
         # finally, the remainder of the filter args in the request
-        props = self.client.db.getclass(self.classname).getprops()
-        for k,v in self.filterspec.items():
-            if not args.has_key(k):
-                if type(v) == type([]):
-                    if isinstance(props[k], hyperdb.String):
-                        l.append(s%(k, ' '.join(v)))
+        if self.classname and self.filterspec:
+            props = self.client.db.getclass(self.classname).getprops()
+            for k,v in self.filterspec.items():
+                if not args.has_key(k):
+                    if type(v) == type([]):
+                        if isinstance(props[k], hyperdb.String):
+                            l.append('%s=%s'%(k, '%20'.join([q(i) for i in v])))
+                        else:
+                            l.append('%s=%s'%(k, ','.join([q(i) for i in v])))
                     else:
-                        l.append(s%(k, ','.join(v)))
-                else:
-                    l.append('%s=%s'%(k, v))
+                        l.append('%s=%s'%(k, q(v)))
         return '%s?%s'%(url, '&'.join(l))
     indexargs_href = indexargs_url
 
